The _additional metadata_ needs to be linked with the _document data_. This is commonly done by listing the filenames of the text documents with the metadata associated with them. Both the **Corpus Editor** and the **Metadata Editor** must have a linked data label before the corpus can be built.

Use the dropdown selectors to select a data label from the corpus to be linked with a data label from the additional metadata.
